#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
#       Barcelona Supercomputing Center - Centro Nacional de Supercomputacion
#       Earth Sciences Department - Computational Earth Sciences
#     
#     Authors: 
#       Joan Sala Calero (joan.sala@bsc.es)
#       Ivan Jose Cernicharo Ortiz (ivan.cernicharo@bsc.es)

import logging
from cdo import *

# Local import
from dqc_wrapper.utils.utils_files import *

"""
Class: Spatial consistency checks
---
- Uses CDO python bindings
- Checks grid type and resolution
"""
class SpatialConsistencyTest:

    def __init__(self, files, gridtype, gridinterval):
        self.logger = logging.getLogger('test04-spatial-consistency')
        self.grid_type = gridtype
        self.grid_int = gridinterval
        self.files = files

    def main(self):
        # For all files
        cdo = Cdo()
        res = True

        # Progress init
        i = 0
        n = len(self.files)

        for f in self.files:
            # Progress update
            i += 1
            print_progress(i, n)
            try:
                info = cdo.griddes(input=f)
            except:
                self.logger.error('Bad file format (cdo cannot read file)')
                print(
                    'ERROR: Bad file format ({})'.format(os.path.basename(f)))
                res = False
                break

            gt, gr = None, None
            for inf in info:
                if 'gridtype' in inf:
                    gt = inf.split('=')[1].strip()
                if 'xinc' in inf:
                    gr = inf.split('=')[1].strip()

            if gt != self.grid_type or gr != self.grid_int:
                res = False
                self.logger.error(
                    'Spatial inconsistency found [{} {}] vs [{} {}]'.format(
                        self.grid_type, self.grid_int, gt, gr))

        # Final message
        if res:
            msg = 'Files are spatially consistent'
            self.logger.info(msg)
            result= 'ok'
        else:
            msg = 'Spatial inconsistencies found. Check log for details'
            self.logger.error(msg)
            result = 'err'

        return {'res': result, 'msg': msg}

